@@ -2,13 +2,14 @@ from typing import Optional, _GenericAlias, Tuple, List, Any
 
 from StructNoSQL.dynamodb.models import DatabasePathElement
 from StructNoSQL.fields import BaseItem, BaseField, MapModel
-from StructNoSQL.field_loader import load as field_load
 from StructNoSQL.practical_logger import message_with_vars
 from StructNoSQL.utils.decimals import float_to_decimal, float_to_decimal_serializer
 
 NoneType = type(None)
 class ActiveSelf:
     pass
+class Undefined:
+    pass
 
 
 def validate_data(value: Any, expected_value_type: Any, item_type_to_return_to: Optional[BaseItem] = None) -> Tuple[Any, bool]:
